@@ -1,5 +1,6 @@
 use yaxpeax_arch::{Arch, Decoder, LengthedInstruction};
 use yaxpeax_arm::armv8::a64::{ARMv8, Instruction, Operand, Opcode, SizeCode, ShiftStyle};
+use yaxpeax_arm::armv8::a64::DecodeError;
 
 fn test_decode(data: [u8; 4], expected: Instruction) {
     let mut reader = yaxpeax_arch::U8Reader::new(&data[..]);
@@ -12,6 +13,17 @@ fn test_decode(data: [u8; 4], expected: Instruction) {
     );
 }
 
+fn test_err(data: [u8; 4], err: DecodeError) {
+    let mut reader = yaxpeax_arch::U8Reader::new(&data[..]);
+    let result = <ARMv8 as Arch>::Decoder::default().decode(&mut reader);
+    assert_eq!(
+        result, Err(err),
+        "expected IncompleteDecoder error for {:02x}{:02x}{:02x}{:02x}:\n  decoded: {:?}\n",
+        data[0], data[1], data[2], data[3],
+        result,
+    );
+}
+
 fn test_display(data: [u8; 4], expected: &'static str) {
     let mut reader = yaxpeax_arch::U8Reader::new(&data[..]);
     let instr = <ARMv8 as Arch>::Decoder::default().decode(&mut reader).unwrap();
@@ -25,6 +37,20 @@ fn test_display(data: [u8; 4], expected: &'static str) {
     );
 }
 
+#[test]
+fn test_neon() {
+    // currently, NEON is incompletely implemented in yaxpeax-arm.
+    test_err([0x00, 0x01, 0x27, 0x1e], DecodeError::IncompleteDecoder);
+    test_display([0xe0, 0x03, 0x13, 0xaa], "mov x0, x19");
+}
+
+#[test]
+fn test_unpredictable() {
+    // could be stx/ldx but Lo1 is `x1` and invalid.
+    test_err([0x00, 0x00, 0x20, 0x08], DecodeError::InvalidOpcode);
+    test_err([0x00, 0xfc, 0x00, 0x12], DecodeError::InvalidOperand);
+}
+
 #[test]
 fn test_display_misc() {
     test_display(
